@@ -42,7 +42,6 @@ pub fn strip_dag(vertex: &str, vertice_to_strip: &str) -> String {
                 idx_to_skip.push(idx_lookahead);
                 idx_lookahead += 1;
             }
-
             continue;
         }
 
@@ -52,12 +51,10 @@ pub fn strip_dag(vertex: &str, vertice_to_strip: &str) -> String {
 
     new_dag.sort();
 
-    // Joins the dag back into desired format (e.g "a-b,b-c,c-d")
     new_dag.join(",")
 }
 
 fn push_if_not_duplicate(current_vertex: String, new_dag: &mut Vec<String>, idx: &usize) -> () {
-    // If idx is 0, there can't be any potential duplicate behind, we can just push
     if *idx != 0 {
         if let Some(vertex) = new_dag.get(idx - 1) {
             match (vertex.chars().last(), current_vertex.chars().last()) {
@@ -67,6 +64,7 @@ fn push_if_not_duplicate(current_vertex: String, new_dag: &mut Vec<String>, idx:
             }
         }
     } else {
+        // If idx is 0, there can't be any potential duplicate behind, we can just push
         new_dag.push(current_vertex);
     }
 }
@@ -107,52 +105,12 @@ fn check_next_vertex<'a>(
                     lookahead_vertex,
                 );
 
-                let new_vertex = Some(format!(
+                Some(format!(
                     "{}-{}",
                     previous_stripped_vertex, stripped_lookahead_vertex
-                ));
-
-                new_vertex
+                ))
             }
             _ => None,
         }
     }
 }
-
-#[cfg(test)]
-mod test {
-    use super::strip_dag;
-    #[test]
-    fn strips_dag_successfully() {
-        let original_dag = "a-b,b-c,c-d,c-d";
-        let vertice_to_strip = "d";
-
-        let expected_dag_result = "a-b,b-c";
-        let stripped_dag = strip_dag(original_dag, vertice_to_strip);
-
-        assert_eq!(expected_dag_result, stripped_dag);
-    }
-    #[test]
-    fn nothing_to_strip_just_remove_duplicates() {
-        let original_dag = "a-b,b-c,c-d,c-d";
-
-        let vertice_to_strip = "x";
-
-        let expected_dag_result = "a-b,b-c,c-d";
-        let stripped_dag = strip_dag(original_dag, vertice_to_strip);
-
-        assert_eq!(expected_dag_result, stripped_dag);
-    }
-
-    #[test]
-    fn strip_alphabetically() {
-        let original_dag = "a-b,b-d,d,d";
-        let vertice_to_strip = "c";
-
-        let expected_dag_result = "a-b,b-d";
-        // What is the utility of non-branched vertices? (single vertices)
-        let stripped_dag = strip_dag(original_dag, vertice_to_strip);
-
-        assert_eq!(expected_dag_result, stripped_dag);
-    }
-}
